import sys
sys.path.insert(0, "..")

import crnt4sbml

network = crnt4sbml.CRNT("../sbml_files/irene2009.xml")

network.basic_report()

print(network.get_c_graph().get_species())

network.print_c_graph()

ldt = network.get_low_deficiency_approach()
ldt.report_deficiency_zero_theorem()
ldt.report_deficiency_one_theorem()

print("")

opt = network.get_mass_conservation_approach()

print("Decision Vector:")
print(opt.get_decision_vector())
print("")

print("Species for concentration bounds:")
print(opt.get_concentration_bounds_species())

bounds = [(1e-2, 1e2)]*10
concentration_bounds = [(1e-2, 1e2)]*4

params_for_global_min, obj_fun_val_for_params = opt.run_optimization(bounds=bounds,
                                                                     concentration_bounds=concentration_bounds,
                                                                     iterations=100)

multistable_param_ind = opt.run_continuity_analysis(species="s3", parameters=params_for_global_min,
                                                    auto_parameters={'PrincipalContinuationParameter': 'C1'})



import sys
sys.path.insert(0, "..")

import crnt4sbml

network = crnt4sbml.CRNT("../sbml_files/Fig1Cii.xml")

opt = network.get_semi_diffusive_approach()

bounds = opt.get_optimization_bounds()
print("bounds")
print(bounds)

params_for_global_min, obj_fun_val_for_params = opt.run_optimization(bounds=bounds, iterations=10, seed=0)

import numpy
numpy.save('params.npy',params_for_global_min)
#params_for_global_min = numpy.load('params.npy')

multistable_param_ind = opt.run_greedy_continuity_analysis(species="s7", parameters=params_for_global_min,
                                                           auto_parameters={'PrincipalContinuationParameter': 're17'})

opt.generate_report()








import sys
sys.path.insert(0, "..")

import crnt4sbml

network = crnt4sbml.CRNT("../sbml_files/Fig1Ci.xml")

opt = network.get_mass_conservation_approach()

bounds, concentration_bounds = opt.get_optimization_bounds()

#bounds = [(1e-2, 1e2)]*12
#concentration_bounds = [(1e-2, 1e2)]*4

print("bounds")
print(bounds)
print("")
print("concentration_bounds")
print(concentration_bounds)
print("")

#params_for_global_min, obj_fun_val_for_params = opt.run_optimization(bounds=bounds, iterations=10,
#                                                                     concentration_bounds=concentration_bounds)

import numpy
#numpy.save('params.npy', params_for_global_min)
params_for_global_min = numpy.load('params.npy')

multistable_param_ind = opt.run_greedy_continuity_analysis(species="s15",
                                                           parameters=params_for_global_min,
                                                           auto_parameters={'PrincipalContinuationParameter': 'C3'})


#multistable_param_ind = opt.run_continuity_analysis(species='s15', parameters=params_for_global_min,
#                                                    auto_parameters={'PrincipalContinuationParameter': 'C3',
#                                                                     'RL0': 0.1, 'RL1': 30, 'DSMAX': 0.1})

opt.generate_report()

